@@ -1,6 +1,7 @@
 import click
 import logging
 from importlib import resources
+from importlib.metadata import version
 
 from .server import Server
 
@@ -58,9 +59,10 @@ def run_server(logfile, port, roc, loglevel):
     port = int(port)
     check_port(port)
     logging.basicConfig(filename=logfile, level=log_level_dict[loglevel],
-                        format='[%(asctime)s] %(levelname)-20s:'
+                        format='[%(asctime)s] %(levelname)-10s:'
                                '%(name)-30s %(message)s')
-    logging.info('Starting zmq-i2c_server instance...')
+    release = version("hexacontroller_sc_server")
+    logging.info(f'Starting hexacontroller_sc_server v{release}')
     regmap_table = retrieve_regmap_path(roc)
     server = Server(port, regmap_table)
     server.run()
